@@ -19,7 +19,7 @@ from model.devices import device
 class Device(device.Device):
     def __init__(self, nm_device):
         device.Device.__init__(self)
-        self._nm_device = device
+        self._nm_device = nm_device
 
     def get_id(self):
         return str(self._nm_device.get_op())
