@@ -16,6 +16,7 @@
 
 from gettext import gettext as _
 import logging
+import os
 
 import gobject
 import gtk
@@ -39,14 +40,12 @@ _LIST_VIEW = 1
 _AUTOSEARCH_TIMEOUT = 1000
 
 def _convert_layout_constant(profile_constant):
-    if profile_constant == profile.RANDOM_LAYOUT:
-        return favoritesview.RANDOM_LAYOUT
-    elif profile_constant == profile.RING_LAYOUT:
-        return favoritesview.RING_LAYOUT
-    else:
-        logging.warning('Incorrect favorites_layout value: %r' % \
-                profile_constant)
-        return favoritesview.RING_LAYOUT
+    for layoutid, layoutclass in favoritesview._LAYOUT_MAP.items():
+        if profile_constant == layoutclass.profile_key:
+            return layoutid
+    logging.warning('Incorrect favorites_layout value: %r' % \
+                    profile_constant)
+    return favoritesview.RING_LAYOUT
 
 class HomeBox(gtk.VBox):
     __gtype_name__ = 'SugarHomeBox'
@@ -109,6 +108,52 @@ class HomeBox(gtk.VBox):
             registry = activity.get_registry()
             activity_info = registry.get_activity(bundle_id)
             ActivityBundle(activity_info.path).uninstall()
+            
+    def show_software_updates_alert(self):
+        alert = Alert()
+        updater_icon = Icon(icon_name='module-updater', 
+                    pixel_size = style.STANDARD_ICON_SIZE)
+        alert.props.icon = updater_icon
+        updater_icon.show()
+        alert.props.title = _('Software Update')
+        alert.props.msg = _('Update your activities to ensure' 
+                            ' compatibility with your new software') 
+
+        cancel_icon = Icon(icon_name='dialog-cancel')
+        alert.add_button(gtk.RESPONSE_CANCEL, _('Cancel'), cancel_icon)
+
+        alert.add_button(gtk.RESPONSE_REJECT, _('Later'))
+
+        erase_icon = Icon(icon_name='dialog-ok')
+        alert.add_button(gtk.RESPONSE_OK, _('Check now'), erase_icon)
+
+        if self._list_view in self.get_children():
+            self._list_view.add_alert(alert)
+        else:
+            self._favorites_view.add_alert(alert)
+        alert.connect('response', self.__software_update_response_cb)
+        
+    def __software_update_response_cb(self, alert, response_id):
+        if self._list_view in self.get_children():
+            self._list_view.remove_alert()
+        else:
+            self._favorites_view.remove_alert()
+
+        if response_id != gtk.RESPONSE_REJECT:
+            update_trigger_file = os.path.expanduser('~/.sugar-update')
+            try:
+                os.unlink(update_trigger_file)
+            except OSError:
+                logging.error('Software-update: Can not remove file %s' % 
+                              update_trigger_file)
+
+        if response_id == gtk.RESPONSE_OK:
+            from controlpanel.gui import ControlPanel
+            panel = ControlPanel()
+            panel.set_transient_for(self.get_toplevel())
+            panel.show()
+            panel.show_section_view('updater')
+            panel.set_section_view_auto_close()
 
     def __toolbar_query_changed_cb(self, toolbar, query):
         query = query.lower()
@@ -118,11 +163,9 @@ class HomeBox(gtk.VBox):
         self._set_view(view, layout)
         if layout is not None:
             current_profile = profile.get_profile()
-            if layout == favoritesview.RANDOM_LAYOUT:
-                current_profile.favorites_layout = profile.RANDOM_LAYOUT
-                current_profile.save()
-            elif layout == favoritesview.RING_LAYOUT:
-                current_profile.favorites_layout = profile.RING_LAYOUT
+            profile_key = favoritesview._LAYOUT_MAP[layout].profile_key
+            if profile_key != current_profile.favorites_layout:
+                current_profile.favorites_layout = profile_key
                 current_profile.save()
             else:
                 logging.warning('Incorrect layout requested: %r' % layout)
@@ -168,6 +211,10 @@ class HomeBox(gtk.VBox):
         if self._favorites_view is not None:
             self._favorites_view.enable_xo_palette()
 
+    def focus_search_entry(self):
+        self._toolbar.search_entry.grab_focus()
+
+
 class HomeToolbar(gtk.Toolbar):
     __gtype_name__ = 'SugarHomeToolbar'
 
@@ -192,15 +239,16 @@ class HomeToolbar(gtk.Toolbar):
         self.insert(tool_item, -1)
         tool_item.show()
 
-        self._search_entry = iconentry.IconEntry()
-        self._search_entry.set_icon_from_name(iconentry.ICON_ENTRY_PRIMARY,
+        self.search_entry = iconentry.IconEntry()
+        self.search_entry.set_icon_from_name(iconentry.ICON_ENTRY_PRIMARY,
                                               'system-search')
-        self._search_entry.add_clear_button()
-        self._search_entry.set_width_chars(25)
-        self._search_entry.connect('activate', self.__entry_activated_cb)
-        self._search_entry.connect('changed', self.__entry_changed_cb)
-        tool_item.add(self._search_entry)
-        self._search_entry.show()
+        self.search_entry.add_clear_button()
+        self.search_entry.set_width_chars(25)
+        self.search_entry.connect('activate', self.__entry_activated_cb)
+        self.search_entry.connect('changed', self.__entry_changed_cb)
+        tool_item.add(self.search_entry)
+        self.search_entry.set_sensitive(False)
+        self.search_entry.show()
 
         self._add_separator(expand=True)
 
@@ -224,8 +272,12 @@ class HomeToolbar(gtk.Toolbar):
     def __view_button_toggled_cb(self, button, view):
         if button.props.active:
             if view == _FAVORITES_VIEW:
+                self.search_entry.set_text('')
+                self.search_entry.set_sensitive(False)
                 self.emit('view-changed', view, button.layout)
             else:
+                self.search_entry.set_sensitive(True)
+                self.search_entry.grab_focus()
                 self.emit('view-changed', view, None)
             
     def _add_separator(self, expand=False):
@@ -246,7 +298,8 @@ class HomeToolbar(gtk.Toolbar):
         if self._query != new_query:
             self._query = new_query
 
-            self._list_button.props.active = True
+            if self._query is not '':
+                self._list_button.props.active = True
             self.emit('query-changed', self._query)
 
     def __entry_changed_cb(self, entry):
@@ -261,7 +314,7 @@ class HomeToolbar(gtk.Toolbar):
 
     def __autosearch_timer_cb(self):
         self._autosearch_timer = None
-        self._search_entry.activate()
+        self.search_entry.activate()
         return False
 
 class FavoritesButton(RadioToolButton):
@@ -278,21 +331,25 @@ class FavoritesButton(RadioToolButton):
         self._layout = _convert_layout_constant(profile_layout_constant)
         self._update_icon()
 
-        # TRANS: label for the freeform layout in the favorites view
-        menu_item = MenuItem(_('Freeform'), 'view-freeform')
-        menu_item.connect('activate', self.__layout_activate_cb,
-                          favoritesview.RANDOM_LAYOUT)
-        self.props.palette.menu.append(menu_item)
-        menu_item.show()
+        # someday, this will be a gtk.Table()
+        layouts_grid = gtk.HBox()
+        layout_item = None
+        for layoutid, layoutclass in sorted(favoritesview._LAYOUT_MAP.items()):
+            layout_item = RadioToolButton(icon_name=layoutclass.icon_name,
+                                          group=layout_item, active=False)
+            if layoutid == self._layout:
+                layout_item.set_active(True)
+            layouts_grid.add(layout_item)
+            layout_item.connect('toggled', self.__layout_activate_cb,
+                                layoutid)
+        layouts_grid.show_all()
+        self.props.palette.set_content(layouts_grid)
+        self.props.palette._update_separators()
 
-        # TRANS: label for the ring layout in the favorites view
-        menu_item = MenuItem(_('Ring'), 'view-radial')
-        menu_item.connect('activate', self.__layout_activate_cb,
-                          favoritesview.RING_LAYOUT)
-        self.props.palette.menu.append(menu_item)
-        menu_item.show()
 
     def __layout_activate_cb(self, menu_item, layout):
+        if not menu_item.get_active():
+            return
         if self._layout == layout and self.props.active:
             return
         elif self._layout != layout:
@@ -304,12 +361,8 @@ class FavoritesButton(RadioToolButton):
             self.emit('toggled')
 
     def _update_icon(self):
-        if self._layout == favoritesview.RANDOM_LAYOUT:
-            self.props.named_icon = 'view-freeform'
-        elif self._layout == favoritesview.RING_LAYOUT:
-            self.props.named_icon = 'view-radial'
-        else:
-            raise ValueError('Invalid layout: %r' % self._layout)
+        self.props.named_icon = favoritesview._LAYOUT_MAP[self._layout]\
+                                .icon_name
 
     def _get_layout(self):
         return self._layout
